==> qt5-examples-5.7.0-2-any.pkg.tar.xz: usr/share/doc/qt/examples/scxml/mediaplayer-common/mainwindow.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtScxml module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:BSD$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** BSD License Usage
** Alternatively, you may use this file under the terms of the BSD license
** as follows:
**
** "Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions are
** met:
**   * Redistributions of source code must retain the above copyright
**     notice, this list of conditions and the following disclaimer.
**   * Redistributions in binary form must reproduce the above copyright
**     notice, this list of conditions and the following disclaimer in
**     the documentation and/or other materials provided with the
**     distribution.
**   * Neither the name of The Qt Company Ltd nor the names of its
**     contributors may be used to endorse or promote products derived
**     from this software without specific prior written permission.
**
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
** LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
** A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
** OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
** SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
** LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
**
** $QT_END_LICENSE$
**
****************************************************************************/

#include "mainwindow.h"
#include "ui_mainwindow.h"

#include <QStringListModel>

QT_USE_NAMESPACE

MainWindow::MainWindow(QWidget *parent) :
    QWidget(parent),
    ui(new Ui::MainWindow)
{
    ui->setupUi(this);

    auto model = new QStringListModel(QStringList() << QStringLiteral("song 1")
                                                    << QStringLiteral("song 2")
                                                    << QStringLiteral("song 3"), this);
    ui->mediaListView->setModel(model);

    connect(ui->mediaListView, &QAbstractItemView::clicked, [model,this](const QModelIndex & index){
        QVariantMap data;
        data.insert(QStringLiteral("media"), model->data(index, Qt::EditRole).toString());
        emit tap(data);
    });
}

MainWindow::~MainWindow()
{
    delete ui;
}

void MainWindow::started(const QVariant &data)
{
    QString media = data.toMap().value("media").toString();
    ui->logText->appendPlainText(QStringLiteral("call on slot started with media '%1'").arg(media));
    ui->statusLabel->setText(QStringLiteral("Playing %1").arg(media));
}

void MainWindow::stopped(const QVariant &data)
{
    QString media = data.toMap().value("media").toString();
    ui->logText->appendPlainText(QStringLiteral("call on slot stopped with media '%1'").arg(media));
    ui->statusLabel->setText(QStringLiteral("Stopped"));
}

==> qt5-examples-5.10.1-1-any.pkg.tar.xz: usr/share/doc/qt/examples/scxml/mediaplayer-common/mainwindow.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtScxml module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:BSD$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** BSD License Usage
** Alternatively, you may use this file under the terms of the BSD license
** as follows:
**
** "Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions are
** met:
**   * Redistributions of source code must retain the above copyright
**     notice, this list of conditions and the following disclaimer.
**   * Redistributions in binary form must reproduce the above copyright
**     notice, this list of conditions and the following disclaimer in
**     the documentation and/or other materials provided with the
**     distribution.
**   * Neither the name of The Qt Company Ltd nor the names of its
**     contributors may be used to endorse or promote products derived
**     from this software without specific prior written permission.
**
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
** LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
** A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
** OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
** SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
** LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
**
** $QT_END_LICENSE$
**
****************************************************************************/

#include "mainwindow.h"
#include "ui_mainwindow.h"

#include <QStringListModel>
#include <QScxmlStateMachine>

QT_USE_NAMESPACE

MainWindow::MainWindow(QScxmlStateMachine *stateMachine, QWidget *parent) :
    QWidget(parent),
    ui(new Ui::MainWindow)
{
    ui->setupUi(this);

    auto model = new QStringListModel(QStringList() << QStringLiteral("song 1")
                                                    << QStringLiteral("song 2")
                                                    << QStringLiteral("song 3"), this);
    ui->mediaListView->setModel(model);

    connect(ui->mediaListView, &QAbstractItemView::clicked,
            [model, stateMachine](const QModelIndex & index) {
        QVariantMap data;
        data.insert(QStringLiteral("media"), model->data(index, Qt::EditRole).toString());
        stateMachine->submitEvent("tap", data);
    });

    stateMachine->connectToEvent("playbackStarted", this, &MainWindow::started);
    stateMachine->connectToEvent("playbackStopped", this, &MainWindow::stopped);
}

MainWindow::~MainWindow()
{
    delete ui;
}

void MainWindow::started(const QScxmlEvent &event)
{
    const QString media = event.data().toMap().value("media").toString();
    ui->logText->appendPlainText(QStringLiteral("call on slot started with media '%1'").arg(media));
    ui->statusLabel->setText(QStringLiteral("Playing %1").arg(media));
}

void MainWindow::stopped(const QScxmlEvent &event)
{
    const QString media = event.data().toMap().value("media").toString();
    ui->logText->appendPlainText(QStringLiteral("call on slot stopped with media '%1'").arg(media));
    ui->statusLabel->setText(QStringLiteral("Stopped"));
}
